@@ -552,13 +552,13 @@ calculate_position(panel *np, int distance,int distancefrom)
     ENTER;
     
     display = gdk_display_get_default ();
-    screen  = gdk_display_get_screen(display,0);
+    screen  = gdk_display_get_default_screen(display);
 
     monitorGeometry = (GdkRectangle*) malloc(sizeof(GdkRectangle));
 
     if (np->monitor >= gdk_screen_get_n_monitors(screen)) {
         np->monitor = 0;
-        ERR("trayer: monitor parameter isn't valid, reseting value to 0\n");
+        ERR("trayer: monitor parameter isn't valid, resetting value to 0\n");
     }
 
     gdk_screen_get_monitor_geometry(screen,np->monitor,monitorGeometry);
